@@ -3,8 +3,7 @@
 from netmiko import ConnectHandler
 from collections import namedtuple
 
-
-class huawei_S5720(object):
+class base_huawei(object):
     def __init__(self,ac_info,dev_info):
         self.username = ac_info.username
         self.password = ac_info.password
@@ -138,4 +137,8 @@ class huawei_S5720(object):
             net_connect.write_channel("return\n")
             net_connect.save_config(cmd="save", confirm=True, confirm_response="y")
             net_connect.disconnect()
-            return True
\ No newline at end of file
+            return True
+
+class huawei_S5720(object):
+    def gen_routing_policy(self):
+        return []
