@@ -3,8 +3,7 @@
 from netmiko import ConnectHandler
 from collections import namedtuple
 
-
-class srx_550(object):
+class base_junos(object):
     def __init__(self, ac_info, dev_info):
         self.username = ac_info.username
         self.password = ac_info.password
@@ -160,4 +159,8 @@ class srx_550(object):
         net_connect.send_config_set(script_list, exit_config_mode=False)
         net_connect.commit()
         net_connect.disconnect()
-        return True
\ No newline at end of file
+        return True
+
+class srx_550(base_junos):
+    def gen_routing_policy(self):
+        return []
\ No newline at end of file
